@@ -6,7 +6,7 @@
  */
 
 #pragma once
-
+#include "kcmutils_version.h"
 #include <KCModule>
 
 class QCheckBox;
@@ -15,7 +15,11 @@ class PIMContactsRunnerConfig : public KCModule
 {
     Q_OBJECT
 public:
-    explicit PIMContactsRunnerConfig(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
+    explicit PIMContactsRunnerConfig(QWidget *parent, const QVariantList &args);
+#else
+    explicit PIMContactsRunnerConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args = QVariantList());
+#endif
 
 public Q_SLOTS:
     void save() override;
